@@ -1,3 +1,13 @@
+/*! \file
+Copyright (c) 2003, The Regents of the University of California, through
+Lawrence Berkeley National Laboratory (subject to receipt of any required 
+approvals from U.S. Dept. of Energy) 
+
+All rights reserved. 
+
+The source code is distributed under BSD license, see the file License.txt
+at the top-level directory.
+*/
 /*! @file
  * \brief Gets matrix permutation
  *
@@ -201,7 +211,7 @@ getata_dist(
 	ABORT("SUPERLU_MALLOC fails for ata_colptr[]");
     if ( *atanz ) {
 	if ( !(*ata_rowind = (int_t*)SUPERLU_MALLOC(*atanz*sizeof(int_t)) ) ) {
-	    fprintf(stderr, ".. atanz = %ld\n", (long long) *atanz);
+	    fprintf(stderr, ".. atanz = %lld\n", (long long) *atanz);
 	    ABORT("SUPERLU_MALLOC fails for ata_rowind[]");
 	}
     }
