@@ -1,3 +1,13 @@
+/*! \file
+Copyright (c) 2003, The Regents of the University of California, through
+Lawrence Berkeley National Laboratory (subject to receipt of any required 
+approvals from U.S. Dept. of Energy) 
+
+All rights reserved. 
+
+The source code is distributed under BSD license, see the file License.txt
+at the top-level directory.
+*/
 /*! @file
  * \brief Gets matrix permutation
  *
@@ -14,6 +24,7 @@
 /* limits.h:  the largest positive integer (INT_MAX) */
 #include <limits.h>
 #include <math.h>
+#include "parmetis.h"
 #include "superlu_ddefs.h"
 
 /*
@@ -101,7 +112,7 @@ get_perm_c_parmetis (SuperMatrix *A, int_t *perm_r, int_t *perm_c,
 #else /* 64-bit integers */
   int_t options[4]={0,0,0,1}, numflag;
 #endif
-  int_t m_loc, nnz_loc, fst_row;
+  int_t m_loc, fst_row;
   int_t m, n, bnz, i, j;
   int_t *rowptr, *colind, *l_fstVtxSep, *l_sizes;
   int_t *b_rowptr, *b_colind;
@@ -127,7 +138,6 @@ get_perm_c_parmetis (SuperMatrix *A, int_t *perm_r, int_t *perm_c,
 #endif
 
   Astore = (NRformat_loc *) A->Store;
-  nnz_loc = Astore->nnz_loc; /* number of nonzeros in the local submatrix */
   m_loc = Astore->m_loc;     /* number of rows local to this processor */
   fst_row = Astore->fst_row; /* global index of the first row */
   rowptr = Astore->rowptr;   /* pointer to rows and column indices */
@@ -195,7 +205,7 @@ get_perm_c_parmetis (SuperMatrix *A, int_t *perm_r, int_t *perm_c,
     if (! (dist_order = (int_t *) SUPERLU_MALLOC(m_loc * sizeof(int_t))))
       ABORT("SUPERLU_MALLOC fails for dist_order.");
 
-#if 0
+#if 0  /* Obsolate -- now ParMETIS has 64 bit integer support. */
 
   /* ParMETIS represents the column pointers and row indices of *
    * the input matrix using integers. When SuperLU_DIST uses    *
@@ -414,13 +424,13 @@ a_plus_at_CompRow_loc
   int_t i, j, k, col, num_nz, nprocs;
   int_t *tcolind_recv; /* temporary receive buffer */
   int_t *tcolind_send; /* temporary send buffer */
-  int_t sz_tcolind_send, sz_tcolind_loc, sz_tcolind_recv;
-  int_t ind, ind_tmp, ind_rcv;
+  int_t sz_tcolind_send, sz_tcolind_recv;
+  int_t ind, ind_rcv;
   int redist_pra; /* TRUE if Pr != I or nprocs_i != nprocs_o */
   int_t *marker, *iperm_r;
   int_t *sendCnts, *recvCnts;
   int_t *sdispls, *rdispls;
-  int_t bnz, *b_rowptr, *b_colind, bnz_t, *b_rowptr_t, *b_colind_t;
+  int_t *b_rowptr, *b_colind, bnz_t, *b_rowptr_t, *b_colind_t;
   int_t p, t_ind, nelts, ipcol;
   int_t m_loc, m_loc_o;      /* number of local rows */ 
   int_t fst_row, fst_row_o;  /* index of first local row */
@@ -489,7 +499,6 @@ a_plus_at_CompRow_loc
   MPI_Alltoall (sendCnts, 1, mpi_int_t,
 		recvCnts, 1, mpi_int_t, grid->comm);
   sendCnts[iam] = 0;
-  sz_tcolind_loc = recvCnts[iam];
   
   for (i = 0, j = 0, p = 0; p < nprocs_i; p++) {
     rdispls[p] = j;
