@@ -1,3 +1,13 @@
+/*! \file
+Copyright (c) 2003, The Regents of the University of California, through
+Lawrence Berkeley National Laboratory (subject to receipt of any required 
+approvals from U.S. Dept. of Energy) 
+
+All rights reserved. 
+
+The source code is distributed under BSD license, see the file License.txt
+at the top-level directory.
+*/
 /*! @file
  * \brief Memory utilities
  *
@@ -540,7 +550,7 @@ static void *expand
  */
 
 int_t QuerySpace_dist(int_t n, int_t lsub_size, Glu_freeable_t *Glu_freeable,
-		      mem_usage_t *mem_usage)
+		      superlu_dist_mem_usage_t *mem_usage)
 /************************************************************************/
 {
     register int_t iword = sizeof(int_t);
