@@ -1,3 +1,13 @@
+/*! \file
+Copyright (c) 2003, The Regents of the University of California, through
+Lawrence Berkeley National Laboratory (subject to receipt of any required 
+approvals from U.S. Dept. of Energy) 
+
+All rights reserved. 
+
+The source code is distributed under BSD license, see the file License.txt
+at the top-level directory.
+*/
 
 
 /*! @file 
@@ -19,7 +29,7 @@
  *
  * Arguments
  * =========
- * options (input) superlu_options_t* (global)
+ * options (input) superlu_dist_options_t* (global)
  *         The structure defines the input parameters to control
  *         how the LU decomposition will be performed.
  *
@@ -67,7 +77,7 @@
 /* This pdgstrf2 is based on TRSM function */
 void
 pdgstrf2_trsm
-    (superlu_options_t * options, int_t k0, int_t k, double thresh,
+    (superlu_dist_options_t * options, int_t k0, int_t k, double thresh,
      Glu_persist_t * Glu_persist, gridinfo_t * grid, LocalLU_t * Llu,
      MPI_Request * U_diag_blk_send_req, int tag_ub,
      SuperLUStat_t * stat, int *info)
