@@ -1,3 +1,13 @@
+/*! \file
+Copyright (c) 2003, The Regents of the University of California, through
+Lawrence Berkeley National Laboratory (subject to receipt of any required 
+approvals from U.S. Dept. of Energy) 
+
+All rights reserved. 
+
+The source code is distributed under BSD license, see the file License.txt
+at the top-level directory.
+*/
 
 /*! @file 
  * \brief Solves a system of linear equations A*X=B,
@@ -210,7 +220,7 @@
  * Arguments
  * =========
  *
- * options (input) superlu_options_t*
+ * options (input) superlu_dist_options_t*
  *         The structure defines the input parameters to control
  *         how the LU decomposition will be performed.
  *         The following fields should be defined for this structure:
@@ -454,7 +464,7 @@
  * </pre>
  */
 void
-pzgssvx_ABglobal(superlu_options_t *options, SuperMatrix *A, 
+pzgssvx_ABglobal(superlu_dist_options_t *options, SuperMatrix *A, 
 		 ScalePermstruct_t *ScalePermstruct,
 		 doublecomplex B[], int ldb, int nrhs, gridinfo_t *grid,
 		 LUstruct_t *LUstruct, double *berr,
@@ -490,7 +500,7 @@ pzgssvx_ABglobal(superlu_options_t *options, SuperMatrix *A,
     double   *C, *R, *C1, *R1, amax, anorm, colcnd, rowcnd;
     doublecomplex   *X, *b_col, *b_work, *x_col;
     double   t;
-    static mem_usage_t num_mem_usage, symb_mem_usage;
+    static superlu_dist_mem_usage_t num_mem_usage, symb_mem_usage;
 #if ( PRNTlevel>= 2 )
     double   dmin, dsum, dprod;
 #endif
