@@ -1,3 +1,13 @@
+/*! \file
+Copyright (c) 2003, The Regents of the University of California, through
+Lawrence Berkeley National Laboratory (subject to receipt of any required 
+approvals from U.S. Dept. of Energy) 
+
+All rights reserved. 
+
+The source code is distributed under BSD license, see the file License.txt
+at the top-level directory.
+*/
 
 /*! @file
  * \brief Performs LU factorization in parallel
@@ -131,7 +141,7 @@
 #define PZGSTRF2 pzgstrf2_trsm
 #define PZGSTRS2 pzgstrs2_omp
 
-extern void PZGSTRF2 (superlu_options_t *, int_t, int_t, double,
+extern void PZGSTRF2 (superlu_dist_options_t *, int_t, int_t, double,
                         Glu_persist_t *, gridinfo_t *, LocalLU_t *,
                         MPI_Request *, int, SuperLUStat_t *, int *);
 #ifdef _CRAY
@@ -160,68 +170,6 @@ superlu_sort_perm (const void *arg1, const void *arg2)
 #endif
 
 
-int get_thread_per_process()
-{   
-    char* ttemp; 
-    ttemp = getenv("THREAD_PER_PROCESS");
-
-    if(ttemp) return atoi(ttemp);
-    else return 1;
-}
-
-int
-get_mic_offload ()
-{
-    char *ttemp;
-    ttemp = getenv ("SUPERLU_MIC_OFFLOAD");
-
-    if (ttemp)
-        return atoi (ttemp);
-    else
-        return 0;
-}
-
-int_t
-get_max_buffer_size ()
-{
-    char *ttemp;
-    ttemp = getenv ("MAX_BUFFER_SIZE");
-    if (ttemp)
-        return atoi (ttemp);
-    else
-        return 5000000;
-}
-
-int_t
-get_cublas_nb ()
-{
-    char *ttemp;
-    ttemp = getenv ("CUBLAS_NB");
-    if (ttemp)
-        return atoi (ttemp);
-    else
-        return 64;
-}
-
-int_t
-get_num_cuda_streams ()
-{
-    char *ttemp;
-    ttemp = getenv ("NUM_CUDA_STREAMS");
-    if (ttemp)
-        return atoi (ttemp);
-    else
-        return 8;
-}
-
-/*int omp_get_num_threads (void);
-  int omp_get_thread_num (void);*/
-
-int AssignMic(int my_rank)
-{
-    return (my_rank+1)%2;
-}
-
 /************************************************************************/
 
 #include "zscatter.c"
@@ -240,7 +188,7 @@ int AssignMic(int my_rank)
  * Arguments
  * =========
  *
- * options (input) superlu_options_t*
+ * options (input) superlu_dist_options_t*
  *         The structure defines the input parameters to control
  *         how the LU decomposition will be performed.
  *         The following field should be defined:
@@ -295,7 +243,7 @@ int AssignMic(int my_rank)
  * </pre>
  */
 int_t
-pzgstrf(superlu_options_t * options, int m, int n, double anorm,
+pzgstrf(superlu_dist_options_t * options, int m, int n, double anorm,
        LUstruct_t * LUstruct, gridinfo_t * grid, SuperLUStat_t * stat, int *info)
 {
 #ifdef _CRAY
@@ -590,8 +538,6 @@ pzgstrf(superlu_options_t * options, int m, int n, double anorm,
     ncb = nsupers / Pc;
     nrb = nsupers / Pr;
 
-    int nstreams = get_num_cuda_streams ();
-    /* int nstreams = NUM_CUDA_STREAMS;    */
     /* in order to have dynamic scheduling */
     int *full_u_cols;
     int *blk_ldu;
@@ -604,13 +550,6 @@ pzgstrf(superlu_options_t * options, int m, int n, double anorm,
 #endif
     log_memory(2 * ncb * iword, stat);
 
-    /* array holding last column blk for each partition,
-       used in SchCompUdt--CUDA.c         */
-#if 0
-    int *stream_end_col = (int_t *) _mm_malloc (sizeof (int_t) * nstreams,64);
-#else
-    int *stream_end_col = SUPERLU_MALLOC( nstreams * sizeof(int) );
-#endif
 
     /* insert a check condition here */
 
@@ -734,7 +673,7 @@ pzgstrf(superlu_options_t * options, int m, int n, double anorm,
          ABORT("Malloc fails for ujrow[].");
 #else
     /* Instead of half storage, we'll do full storage */
-    if (!(Llu->ujrow = doublecomplexMalloc_dist (k * k)))
+    if (!(Llu->ujrow = doublecomplexCalloc_dist (k * k)))
         ABORT ("Malloc fails for ujrow[].");
     log_memory(k * k * iword, stat);
 #endif
@@ -786,10 +725,21 @@ pzgstrf(superlu_options_t * options, int m, int n, double anorm,
          SUPERLU_MAX (max_row_size * num_threads * ldt,
                       get_max_buffer_size ());           */
             
-    int cublas_nb = get_cublas_nb();
 #ifdef GPU_ACC
+    int cublas_nb = get_cublas_nb();
+    int nstreams = get_num_cuda_streams ();
+
     int buffer_size  = SUPERLU_MAX(max_row_size*nstreams*cublas_nb,get_max_buffer_size());
+    /* array holding last column blk for each partition,
+       used in SchCompUdt--CUDA.c         */
+  #if 0
+    int *stream_end_col = (int_t *) _mm_malloc (sizeof (int_t) * nstreams,64);
+  #else
+    int *stream_end_col = SUPERLU_MALLOC( nstreams * sizeof(int) );
+  #endif
+
 #else 
+
     int Threads_per_process = get_thread_per_process();
     int buffer_size  = SUPERLU_MAX(max_row_size*Threads_per_process*ldt,get_max_buffer_size());
 #endif 
@@ -1716,6 +1666,7 @@ pzgstrf(superlu_options_t * options, int m, int n, double anorm,
     cudaFree( (void*)dC );
     SUPERLU_FREE( handle );
     SUPERLU_FREE( streams );
+    SUPERLU_FREE( stream_end_col );
 #else
     SUPERLU_FREE (bigV);
     SUPERLU_FREE (bigU);
@@ -1741,7 +1692,6 @@ pzgstrf(superlu_options_t * options, int m, int n, double anorm,
     SUPERLU_FREE(blk_ldu);
     log_memory(-2 * ncb * dword, stat);
 
-    SUPERLU_FREE(stream_end_col);
     SUPERLU_FREE(lookAheadFullRow);
     SUPERLU_FREE(lookAheadStRow);
     SUPERLU_FREE(lookAhead_lptr);
@@ -1812,8 +1762,8 @@ pzgstrf(superlu_options_t * options, int m, int n, double anorm,
 #if ( DEBUGlevel>=2 )
     for (i = 0; i < Pr * Pc; ++i) {
         if (iam == i) {
-            dPrintLblocks (iam, nsupers, grid, Glu_persist, Llu);
-            dPrintUblocks (iam, nsupers, grid, Glu_persist, Llu);
+            zPrintLblocks (iam, nsupers, grid, Glu_persist, Llu);
+            zPrintUblocks (iam, nsupers, grid, Glu_persist, Llu);
             printf ("(%d)\n", iam);
             PrintInt10 ("Recv", nsupers, Llu->ToRecv);
         }
