@@ -1,3 +1,13 @@
+/*! \file
+Copyright (c) 2003, The Regents of the University of California, through
+Lawrence Berkeley National Laboratory (subject to receipt of any required 
+approvals from U.S. Dept. of Energy) 
+
+All rights reserved. 
+
+The source code is distributed under BSD license, see the file License.txt
+at the top-level directory.
+*/
 /*! @file
  * \brief Performs static scheduling for the look-ahead factorization algorithm.
  *
@@ -33,7 +43,7 @@ superlu_sort_perm (const void *arg1, const void *arg2)
 #endif
 
 int
-static_schedule(superlu_options_t * options, int m, int n, 
+static_schedule(superlu_dist_options_t * options, int m, int n, 
 		LUstruct_t * LUstruct, gridinfo_t * grid, SuperLUStat_t * stat,
 		int_t *perm_c_supno, int_t *iperm_c_supno, int *info)
 {
