@@ -1,3 +1,13 @@
+/*! \file
+Copyright (c) 2003, The Regents of the University of California, through
+Lawrence Berkeley National Laboratory (subject to receipt of any required 
+approvals from U.S. Dept. of Energy) 
+
+All rights reserved. 
+
+The source code is distributed under BSD license, see the file License.txt
+at the top-level directory.
+*/
 
 
 /*! @file 
@@ -245,23 +255,23 @@ extern int     sp_dgemm_dist (char *, int, double, SuperMatrix *,
 
 extern float ddistribute(fact_t, int_t, SuperMatrix *, Glu_freeable_t *, 
 			 LUstruct_t *, gridinfo_t *);
-extern void  pdgssvx_ABglobal(superlu_options_t *, SuperMatrix *, 
+extern void  pdgssvx_ABglobal(superlu_dist_options_t *, SuperMatrix *, 
 			      ScalePermstruct_t *, double *,
 			      int, int, gridinfo_t *, LUstruct_t *, double *,
 			      SuperLUStat_t *, int *);
 extern float pddistribute(fact_t, int_t, SuperMatrix *, 
 			 ScalePermstruct_t *, Glu_freeable_t *, 
 			 LUstruct_t *, gridinfo_t *);
-extern void  pdgssvx(superlu_options_t *, SuperMatrix *, 
+extern void  pdgssvx(superlu_dist_options_t *, SuperMatrix *, 
 		     ScalePermstruct_t *, double *,
 		     int, int, gridinfo_t *, LUstruct_t *,
 		     SOLVEstruct_t *, double *, SuperLUStat_t *, int *);
-extern int  dSolveInit(superlu_options_t *, SuperMatrix *, int_t [], int_t [],
+extern int  dSolveInit(superlu_dist_options_t *, SuperMatrix *, int_t [], int_t [],
 		       int_t, LUstruct_t *, gridinfo_t *, SOLVEstruct_t *);
-extern void dSolveFinalize(superlu_options_t *, SOLVEstruct_t *);
+extern void dSolveFinalize(superlu_dist_options_t *, SOLVEstruct_t *);
 extern int  dldperm_dist(int_t, int_t, int_t, int_t [], int_t [],
 		    double [], int_t *, double [], double []);
-extern int  static_schedule(superlu_options_t *, int, int, 
+extern int  static_schedule(superlu_dist_options_t *, int, int, 
 		            LUstruct_t *, gridinfo_t *, SuperLUStat_t *,
 			    int_t *, int_t *, int *);
 extern void LUstructInit(const int_t, LUstruct_t *);
@@ -271,7 +281,7 @@ extern void Destroy_LU(int_t, gridinfo_t *, LUstruct_t *);
 /* #define GPU_PROF
 #define IPM_PROF */
 
-extern int_t pdgstrf(superlu_options_t *, int, int, double,
+extern int_t pdgstrf(superlu_dist_options_t *, int, int, double,
 		    LUstruct_t*, gridinfo_t*, SuperLUStat_t*, int*);
 extern void pdgstrs_Bglobal(int_t, LUstruct_t *, gridinfo_t *,
 			     double *, int_t, int, SuperLUStat_t *, int *);
@@ -312,7 +322,7 @@ extern double  *doubleCalloc_dist(int_t);
 extern void  *duser_malloc_dist (int_t, int_t);
 extern void  duser_free_dist (int_t, int_t);
 extern int_t dQuerySpace_dist(int_t, LUstruct_t *, gridinfo_t *,
-			      SuperLUStat_t *, mem_usage_t *);
+			      SuperLUStat_t *, superlu_dist_mem_usage_t *);
 
 /* Auxiliary routines */
 extern void    dfill_dist (double *, int_t, double);
@@ -322,17 +332,18 @@ extern void    pdinf_norm_error(int, int_t, int_t, double [], int_t,
 				double [], int_t , gridinfo_t *);
 extern void  dreadhb_dist (int, FILE *, int_t *, int_t *, int_t *, 
 			   double **, int_t **, int_t **);
-extern void  dreadtriple(FILE *, int_t *, int_t *, int_t *,
+extern void  dreadtriple_dist(FILE *, int_t *, int_t *, int_t *,
 			 double **, int_t **, int_t **);
 extern void  dreadrb_dist(int, FILE *, int_t *, int_t *, int_t *,
 		     double **, int_t **, int_t **);
-extern void  dreadMM(FILE *, int_t *, int_t *, int_t *,
+extern void  dreadMM_dist(FILE *, int_t *, int_t *, int_t *,
 	                  double **, int_t **, int_t **);
 
 /* Distribute the data for numerical factorization */
 extern float ddist_psymbtonum(fact_t, int_t, SuperMatrix *,
                                 ScalePermstruct_t *, Pslu_freeable_t *, 
                                 LUstruct_t *, gridinfo_t *);
+extern void pdGetDiagU(int_t, LUstruct_t *, gridinfo_t *, double *);
 
 
 /* Routines for debugging */
@@ -349,9 +360,9 @@ extern int   file_PrintDouble5(FILE *, char *, int_t, double *);
 /* BLAS */
 
 #ifdef USE_VENDOR_BLAS
-extern void dgemm_(char*, char*, int*, int*, int*,
-                  double*, double*, int*, double*,
-                  int*, double*, double*, int*, int, int);
+extern void dgemm_(const char*, const char*, const int*, const int*, const int*,
+                  const double*, const double*, const int*, const double*,
+                  const int*, const double*, double*, const int*, int, int);
 extern void dtrsv_(char*, char*, char*, int*, double*, int*,
                   double*, int*, int, int, int);
 extern void dtrsm_(char*, char*, char*, char*, int*, int*, 
@@ -363,9 +374,9 @@ extern void dger_(int*, int*, double*, double*, int*,
                  double*, int*, double*, int*);
 
 #else
-extern int dgemm_(char*, char*, int*, int*, int*,
-                   double*,  double*,  int*,  double*,
-                   int*,  double*, double*, const int*);
+extern int dgemm_(const char*, const char*, const int*, const int*, const int*,
+                   const double*,  const double*,  const int*,  const double*,
+                   const int*,  const double*, double*, const int*);
 extern int dtrsv_(char*, char*, char*, int*, double*, int*,
                   double*, int*);
 extern int dtrsm_(char*, char*, char*, char*, int*, int*, 
