@@ -1,3 +1,13 @@
+/*! \file
+Copyright (c) 2003, The Regents of the University of California, through
+Lawrence Berkeley National Laboratory (subject to receipt of any required 
+approvals from U.S. Dept. of Energy) 
+
+All rights reserved. 
+
+The source code is distributed under BSD license, see the file License.txt
+at the top-level directory.
+*/
 /*! @file
  * \brief Definitions which are precision-neutral
  *
@@ -21,7 +31,6 @@
  */
 #ifdef _CRAY
     #include <fortran.h>
-    #include <string.h>
 #endif
 
 #ifdef _OPENMP
@@ -32,7 +41,24 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <limits.h>
+#include <string.h>
 
+/*************************************************************************
+ * Constants
+ **************************************************************************/
+/*
+ * You can support older version of SuperLU_DIST.
+ * At compile-time, you can catch the new release as:
+ *   #ifdef SUPERLU_DIST_MAIN_VERSION == 5
+ *       use the new interface
+ *   #else
+ *       use the old interface
+ *   #endif
+ * Versions 4.x and earlier do not include a #define'd version numbers.
+ */
+#define SUPERLU_DIST_MAJOR_VERSION     5
+#define SUPERLU_DIST_MINOR_VERSION     1
+#define SUPERLU_DIST_PATCH_VERSION     0
 
 /* Define my integer size int_t */
 #ifdef _CRAY
@@ -537,14 +563,14 @@ typedef struct {
     yes_no_t      lookahead_etree; /* use etree computed from the
 				      serial symbolic factorization */
     yes_no_t      SymPattern;      /* symmetric factorization          */
-} superlu_options_t;
+} superlu_dist_options_t;
 
 typedef struct {
     float for_lu;
     float total;
     int_t expansions;
     long long int nnzL, nnzU;
-} mem_usage_t;
+} superlu_dist_mem_usage_t;
 
 /* 
  *-- The new structures added in the hybrid CUDA + OpenMP + MPI code.
@@ -586,20 +612,20 @@ struct pair
 extern "C" {
 #endif
 
-extern void   set_default_options_dist(superlu_options_t *);
+extern void   set_default_options_dist(superlu_dist_options_t *);
 extern void   superlu_gridinit(MPI_Comm, int_t, int_t, gridinfo_t *);
 extern void   superlu_gridmap(MPI_Comm, int_t, int_t, int_t [], int_t,
 			      gridinfo_t *);
 extern void   superlu_gridexit(gridinfo_t *);
-extern void   print_options_dist(superlu_options_t *);
-extern void   print_sp_ienv_dist(superlu_options_t *);
+extern void   print_options_dist(superlu_dist_options_t *);
+extern void   print_sp_ienv_dist(superlu_dist_options_t *);
 extern void   Destroy_CompCol_Matrix_dist(SuperMatrix *);
 extern void   Destroy_SuperNode_Matrix_dist(SuperMatrix *);
 extern void   Destroy_SuperMatrix_Store_dist(SuperMatrix *);
 extern void   Destroy_CompCol_Permuted_dist(SuperMatrix *);
 extern void   Destroy_CompRowLoc_Matrix_dist(SuperMatrix *);
 extern void   Destroy_CompRow_Matrix_dist(SuperMatrix *);
-extern void   sp_colorder (superlu_options_t*, SuperMatrix*, int_t*, int_t*,
+extern void   sp_colorder (superlu_dist_options_t*, SuperMatrix*, int_t*, int_t*,
 			   SuperMatrix*);
 extern int    sp_symetree_dist(int_t *, int_t *, int_t *, int_t, int_t *);
 extern int    sp_coletree_dist (int_t *, int_t *, int_t *, int_t, int_t, int_t *);
@@ -611,7 +637,7 @@ extern int    genmmd_dist_(int_t *, int_t *, int_t *a,
 			   int_t *, int_t *, int_t *, int_t *, int_t *);
 extern void  bcast_tree(void *, int, MPI_Datatype, int, int,
 			gridinfo_t *, int, int *);
-extern int_t symbfact(superlu_options_t *, int, SuperMatrix *, int_t *,
+extern int_t symbfact(superlu_dist_options_t *, int, SuperMatrix *, int_t *,
                       int_t *, Glu_persist_t *, Glu_freeable_t *);
 extern int_t symbfact_SubInit(fact_t, void *, int_t, int_t, int_t, int_t,
 			      Glu_persist_t *, Glu_freeable_t *);
@@ -624,8 +650,8 @@ extern void    countnz_dist (const int_t, int_t *,
 extern long long int fixupL_dist (const int_t, const int_t *, Glu_persist_t *,
 				  Glu_freeable_t *);
 extern int_t   *TreePostorder_dist (int_t, int_t *);
-extern float   smach(char *);
-extern double  dmach(char *);
+extern float   smach_dist(char *);
+extern double  dmach_dist(char *);
 extern void    *superlu_malloc_dist (size_t);
 extern void    superlu_free_dist (void*);
 extern int_t   *intMalloc_dist (int_t);
@@ -636,8 +662,6 @@ extern int_t   mc64id_dist(int_t *);
 extern double SuperLU_timer_ ();
 extern void   superlu_abort_and_exit_dist(char *);
 extern int_t  sp_ienv_dist (int_t);
-extern int    lsame_ (char *, char *);
-extern int    xerbla_ (char *, int *);
 extern void   ifill_dist (int_t *, int_t, int_t);
 extern void   super_stats_dist (int_t, int_t *);
 extern void   ScalePermstructInit(const int_t, const int_t, 
@@ -645,19 +669,19 @@ extern void   ScalePermstructInit(const int_t, const int_t,
 extern void   ScalePermstructFree(ScalePermstruct_t *);
 extern void  get_diag_procs(int_t, Glu_persist_t *, gridinfo_t *, int_t *,
 			    int_t **, int_t **);
-extern int_t QuerySpace_dist(int_t, int_t, Glu_freeable_t *, mem_usage_t *);
-extern int   xerbla_ (char *, int *);
-extern void  pxerbla (char *, gridinfo_t *, int_t);
+extern int_t QuerySpace_dist(int_t, int_t, Glu_freeable_t *, superlu_dist_mem_usage_t *);
+extern int   xerr_dist (char *, int *);
+extern void  pxerr_dist (char *, gridinfo_t *, int_t);
 extern void  PStatInit(SuperLUStat_t *);
 extern void  PStatFree(SuperLUStat_t *);
-extern void  PStatPrint(superlu_options_t *, SuperLUStat_t *, gridinfo_t *);
+extern void  PStatPrint(superlu_dist_options_t *, SuperLUStat_t *, gridinfo_t *);
 extern void  log_memory(long long, SuperLUStat_t *);
 extern void  print_memorylog(SuperLUStat_t *, char *);
 
 /* Prototypes for parallel symbolic factorization */
 extern float symbfact_dist
 (int,  int, SuperMatrix *, int_t *, int_t *,  int_t *, int_t *,
- Pslu_freeable_t *, MPI_Comm *, MPI_Comm *,  mem_usage_t *);
+ Pslu_freeable_t *, MPI_Comm *, MPI_Comm *,  superlu_dist_mem_usage_t *);
 
 /* Get the column permutation using parmetis */
 extern float get_perm_c_parmetis 
@@ -685,8 +709,17 @@ extern int_t psymbfact_prLUXpand
 #ifdef GPU_ACC   /* GPU related */
 extern void gemm_division_cpu_gpu (int *, int *, int *, int,
 				   int, int, int *, int);
+extern int_t get_cublas_nb ();
+extern int_t get_num_cuda_streams ();
 #endif
 
+extern int compare_pair (const void *, const void *);
+extern int get_thread_per_process();
+extern int_t get_max_buffer_size ();
+extern int_t get_min (int_t *, int_t);
+extern int_t static_partition (struct pair *, int_t, int_t *, int_t,
+			       int_t *, int_t *, int);
+
 /* Routines for debugging */
 extern void  print_panel_seg_dist(int_t, int_t, int_t, int_t, int_t *, int_t *);
 extern void  check_repfnz_dist(int_t, int_t, int_t, int_t *);
