@@ -1,3 +1,13 @@
+/*! \file
+Copyright (c) 2003, The Regents of the University of California, through
+Lawrence Berkeley National Laboratory (subject to receipt of any required 
+approvals from U.S. Dept. of Energy) 
+
+All rights reserved. 
+
+The source code is distributed under BSD license, see the file License.txt
+at the top-level directory.
+*/
 
 /*! @file 
  * \brief  Distributed SuperLU data types and function prototypes
@@ -245,23 +255,23 @@ extern int     sp_zgemm_dist (char *, int, doublecomplex, SuperMatrix *,
 
 extern float zdistribute(fact_t, int_t, SuperMatrix *, Glu_freeable_t *, 
 			 LUstruct_t *, gridinfo_t *);
-extern void  pzgssvx_ABglobal(superlu_options_t *, SuperMatrix *, 
+extern void  pzgssvx_ABglobal(superlu_dist_options_t *, SuperMatrix *, 
 			      ScalePermstruct_t *, doublecomplex *,
 			      int, int, gridinfo_t *, LUstruct_t *, double *,
 			      SuperLUStat_t *, int *);
 extern float pzdistribute(fact_t, int_t, SuperMatrix *, 
 			 ScalePermstruct_t *, Glu_freeable_t *, 
 			 LUstruct_t *, gridinfo_t *);
-extern void  pzgssvx(superlu_options_t *, SuperMatrix *, 
+extern void  pzgssvx(superlu_dist_options_t *, SuperMatrix *, 
 		     ScalePermstruct_t *, doublecomplex *,
 		     int, int, gridinfo_t *, LUstruct_t *,
 		     SOLVEstruct_t *, double *, SuperLUStat_t *, int *);
-extern int  zSolveInit(superlu_options_t *, SuperMatrix *, int_t [], int_t [],
+extern int  zSolveInit(superlu_dist_options_t *, SuperMatrix *, int_t [], int_t [],
 		       int_t, LUstruct_t *, gridinfo_t *, SOLVEstruct_t *);
-extern void zSolveFinalize(superlu_options_t *, SOLVEstruct_t *);
+extern void zSolveFinalize(superlu_dist_options_t *, SOLVEstruct_t *);
 extern int  zldperm_dist(int_t, int_t, int_t, int_t [], int_t [],
 		    doublecomplex [], int_t *, double [], double []);
-extern int  static_schedule(superlu_options_t *, int, int, 
+extern int  static_schedule(superlu_dist_options_t *, int, int, 
 		            LUstruct_t *, gridinfo_t *, SuperLUStat_t *,
 			    int_t *, int_t *, int *);
 extern void LUstructInit(const int_t, LUstruct_t *);
@@ -271,7 +281,7 @@ extern void Destroy_LU(int_t, gridinfo_t *, LUstruct_t *);
 /* #define GPU_PROF
 #define IPM_PROF */
 
-extern int_t pzgstrf(superlu_options_t *, int, int, double,
+extern int_t pzgstrf(superlu_dist_options_t *, int, int, double,
 		    LUstruct_t*, gridinfo_t*, SuperLUStat_t*, int*);
 extern void pzgstrs_Bglobal(int_t, LUstruct_t *, gridinfo_t *,
 			     doublecomplex *, int_t, int, SuperLUStat_t *, int *);
@@ -314,7 +324,7 @@ extern double  *doubleCalloc_dist(int_t);
 extern void  *duser_malloc_dist (int_t, int_t);
 extern void  duser_free_dist (int_t, int_t);
 extern int_t zQuerySpace_dist(int_t, LUstruct_t *, gridinfo_t *,
-			      SuperLUStat_t *, mem_usage_t *);
+			      SuperLUStat_t *, superlu_dist_mem_usage_t *);
 
 /* Auxiliary routines */
 extern void    zfill_dist (doublecomplex *, int_t, doublecomplex);
@@ -324,17 +334,18 @@ extern void    pzinf_norm_error(int, int_t, int_t, doublecomplex [], int_t,
 				doublecomplex [], int_t , gridinfo_t *);
 extern void  zreadhb_dist (int, FILE *, int_t *, int_t *, int_t *, 
 			   doublecomplex **, int_t **, int_t **);
-extern void  zreadtriple(FILE *, int_t *, int_t *, int_t *,
+extern void  zreadtriple_dist(FILE *, int_t *, int_t *, int_t *,
 			 doublecomplex **, int_t **, int_t **);
 extern void  zreadrb_dist(int, FILE *, int_t *, int_t *, int_t *,
 		     doublecomplex **, int_t **, int_t **);
-extern void  zreadMM(FILE *, int_t *, int_t *, int_t *,
+extern void  zreadMM_dist(FILE *, int_t *, int_t *, int_t *,
 	                  doublecomplex **, int_t **, int_t **);
 
 /* Distribute the data for numerical factorization */
 extern float zdist_psymbtonum(fact_t, int_t, SuperMatrix *,
                                 ScalePermstruct_t *, Pslu_freeable_t *, 
                                 LUstruct_t *, gridinfo_t *);
+extern void pzGetDiagU(int_t, LUstruct_t *, gridinfo_t *, doublecomplex *);
 
 
 /* Routines for debugging */
@@ -352,9 +363,9 @@ extern int   file_PrintDoublecomplex(FILE *fp, char *, int_t, doublecomplex *);
 /* BLAS */
 
 #ifdef USE_VENDOR_BLAS
-extern void zgemm_(char*, char*, int*, int*, int*,
-                  doublecomplex*, doublecomplex*, int*, doublecomplex*,
-                  int*, doublecomplex*, doublecomplex*, int*, int, int);
+extern void zgemm_(const char*, const char*, const int*, const int*, const int*,
+                  const doublecomplex*, const doublecomplex*, const int*, const doublecomplex*,
+                  const int*, const doublecomplex*, doublecomplex*, const int*, int, int);
 extern void ztrsv_(char*, char*, char*, int*, doublecomplex*, int*,
                   doublecomplex*, int*, int, int, int);
 extern void ztrsm_(char*, char*, char*, char*, int*, int*, 
@@ -366,9 +377,9 @@ extern void zgeru_(int*, int*, doublecomplex*, doublecomplex*, int*,
                  doublecomplex*, int*, doublecomplex*, int*);
 
 #else
-extern int zgemm_(char*, char*, int*, int*, int*,
-                   doublecomplex*,  doublecomplex*,  int*,  doublecomplex*,
-                   int*,  doublecomplex*, doublecomplex*, const int*);
+extern int zgemm_(const char*, const char*, const int*, const int*, const int*,
+                   const doublecomplex*,  const doublecomplex*,  const int*,  const doublecomplex*,
+                   const int*,  const doublecomplex*, doublecomplex*, const int*);
 extern int ztrsv_(char*, char*, char*, int*, doublecomplex*, int*,
                   doublecomplex*, int*);
 extern int ztrsm_(char*, char*, char*, char*, int*, int*, 
