@@ -1,3 +1,13 @@
+/*! \file
+Copyright (c) 2003, The Regents of the University of California, through
+Lawrence Berkeley National Laboratory (subject to receipt of any required 
+approvals from U.S. Dept. of Energy) 
+
+All rights reserved. 
+
+The source code is distributed under BSD license, see the file License.txt
+at the top-level directory.
+*/
 /*! @file
  * \brief Utilities functions
  *
@@ -259,7 +269,6 @@ countnz_dist(const int_t n, int_t *xprune,
 }
 
 
-
 /*! \brief
  *
  * <pre>
@@ -307,7 +316,7 @@ fixupL_dist(const int_t n, const int_t *perm_r,
 
 /*! \brief Set the default values for the options argument.
  */
-void set_default_options_dist(superlu_options_t *options)
+void set_default_options_dist(superlu_dist_options_t *options)
 {
     options->Fact              = DOFACT;
     options->Equil             = YES;
@@ -327,7 +336,7 @@ void set_default_options_dist(superlu_options_t *options)
 
 /*! \brief Print the options setting.
  */
-void print_options_dist(superlu_options_t *options)
+void print_options_dist(superlu_dist_options_t *options)
 {
     if ( options->PrintStat == NO ) return;
 
@@ -335,11 +344,12 @@ void print_options_dist(superlu_options_t *options)
     printf(".. options:\n");
     printf("**    Fact             : %4d\n", options->Fact);
     printf("**    Equil            : %4d\n", options->Equil);
+    printf("**    ParSymbFact      : %4d\n", options->ParSymbFact);
     printf("**    ColPerm          : %4d\n", options->ColPerm);
     printf("**    RowPerm          : %4d\n", options->RowPerm);
     printf("**    ReplaceTinyPivot : %4d\n", options->ReplaceTinyPivot);
-    printf("**    Trans            : %4d\n", options->Trans);
     printf("**    IterRefine       : %4d\n", options->IterRefine);
+    printf("**    Trans            : %4d\n", options->Trans);
     printf("**    num_lookaheads   : %4d\n", options->num_lookaheads);
     printf("**    SymPattern       : %4d\n", options->SymPattern);
     printf("**    lookahead_etree  : %4d\n", options->lookahead_etree);
@@ -348,7 +358,7 @@ void print_options_dist(superlu_options_t *options)
 
 /*! \brief Print the blocking parameters.
  */
-void print_sp_ienv_dist(superlu_options_t *options)
+void print_sp_ienv_dist(superlu_dist_options_t *options)
 {
     if ( options->PrintStat == NO ) return;
 
@@ -563,7 +573,7 @@ PStatInit(SuperLUStat_t *stat)
 }
 
 void
-PStatPrint(superlu_options_t *options, SuperLUStat_t *stat, gridinfo_t *grid)
+PStatPrint(superlu_dist_options_t *options, SuperLUStat_t *stat, gridinfo_t *grid)
 {
     double  *utime = stat->utime;
     flops_t *ops = stat->ops;
@@ -946,3 +956,95 @@ void print_memorylog(SuperLUStat_t *stat, char *msg) {
     printf("__ %s (MB):\n\tcurrent_buffer : %8.2f\tpeak_buffer : %8.2f\n",
 	   msg, stat->current_buffer, stat->peak_buffer);
 }
+
+
+int compare_pair (const void *a, const void *b)
+{
+    return (((struct pair *) a)->val - ((struct pair *) b)->val);
+}
+
+int get_thread_per_process()
+{   
+    char* ttemp; 
+    ttemp = getenv("THREAD_PER_PROCESS");
+
+    if(ttemp) return atoi(ttemp);
+    else return 1;
+}
+
+int_t
+get_max_buffer_size ()
+{
+    char *ttemp;
+    ttemp = getenv ("MAX_BUFFER_SIZE");
+    if (ttemp)
+        return atoi (ttemp);
+    else
+        return 5000000;
+}
+
+int_t
+get_cublas_nb ()
+{
+    char *ttemp;
+    ttemp = getenv ("CUBLAS_NB");
+    if (ttemp)
+        return atoi (ttemp);
+    else
+        return 64;
+}
+
+int_t
+get_num_cuda_streams ()
+{
+    char *ttemp;
+    ttemp = getenv ("NUM_CUDA_STREAMS");
+    if (ttemp)
+        return atoi (ttemp);
+    else
+        return 8;
+}
+
+int_t
+get_min (int_t * sums, int_t nprocs)
+{
+    int_t min_ind, min_val;
+    min_ind = 0;
+    min_val = 2147483647;
+    for (int i = 0; i < nprocs; i++)
+    {
+        if (sums[i] < min_val)
+        {
+            min_val = sums[i];
+            min_ind = i;
+        }
+    }
+
+    return min_ind;
+}
+
+int_t
+static_partition (struct pair *work_load, int_t nwl, int_t *partition,
+		  int_t ldp, int_t * sums, int_t * counts, int nprocs)
+{
+    //initialization loop
+    for (int i = 0; i < nprocs; ++i)
+    {
+        counts[i] = 0;
+        sums[i] = 0;
+    }
+    qsort (work_load, nwl, sizeof (struct pair), compare_pair);
+    // for(int i=0;i<nwl;i++)
+    for (int i = nwl - 1; i >= 0; i--)
+    {
+        int_t ind = get_min (sums, nprocs);
+        // printf("ind %d\n",ind );
+        partition[ldp * ind + counts[ind]] = work_load[i].ind;
+        counts[ind]++;
+        sums[ind] += work_load[i].val;
+
+    }
+
+    return 0;
+}
+
