@@ -1,3 +1,13 @@
+/*! \file
+Copyright (c) 2003, The Regents of the University of California, through
+Lawrence Berkeley National Laboratory (subject to receipt of any required 
+approvals from U.S. Dept. of Energy) 
+
+All rights reserved. 
+
+The source code is distributed under BSD license, see the file License.txt
+at the top-level directory.
+*/
 
 
 /*! @file 
@@ -23,7 +33,7 @@
  */
 
 void
-zreadMM(FILE *fp, int_t *m, int_t *n, int_t *nonz,
+zreadMM_dist(FILE *fp, int_t *m, int_t *n, int_t *nonz,
 	    doublecomplex **nzval, int_t **rowind, int_t **colptr)
 {
     int_t    j, k, jsize, nnz, nz, new_nonz;
@@ -68,7 +78,7 @@ zreadMM(FILE *fp, int_t *m, int_t *n, int_t *nonz,
 
      if(strcmp(arith,"real")) {
        if(!strcmp(arith,"complex")) {
-         printf("Complex matrix; use zreadtriple instead!\n");
+         printf("Complex matrix; use zreadMM instead!\n");
          exit(-1);
        }
        else if(!strcmp(arith, "pattern")) {
@@ -111,7 +121,7 @@ zreadMM(FILE *fp, int_t *m, int_t *n, int_t *nonz,
       new_nonz = *nonz;
 
     *m = *n;
-    printf("m %ld, n %ld, nonz %ld\n", (long long) *m, (long long) *n, (long long) *nonz);
+    printf("m %lld, n %lld, nonz %lld\n", (long long) *m, (long long) *n, (long long) *nonz);
     zallocateA_dist(*n, new_nonz, nzval, rowind, colptr); /* Allocate storage */
     a    = *nzval;
     asub = *rowind;
@@ -129,7 +139,7 @@ zreadMM(FILE *fp, int_t *m, int_t *n, int_t *nonz,
     /* 4/ Read triplets of values */
     for (nnz = 0, nz = 0; nnz < *nonz; ++nnz) {
 #ifdef _LONGINT
-	fscanf(fp, "%ld%ld%lf%lf\n", &row[nz], &col[nz], &val[nz].r, &val[nz].i);
+	fscanf(fp, "%lld%lld%lf%lf\n", &row[nz], &col[nz], &val[nz].r, &val[nz].i);
 #else
 	fscanf(fp, "%d%d%lf%lf\n", &row[nz], &col[nz], &val[nz].r, &val[nz].i);
 #endif
@@ -213,7 +223,7 @@ zreadMM(FILE *fp, int_t *m, int_t *n, int_t *nonz,
 }
 
 
-void zreadrhs(int m, doublecomplex *b)
+static void zreadrhs(int m, doublecomplex *b)
 {
     FILE *fp, *fopen();
     int i;
